@@ -326,7 +326,10 @@ DEFUN(_IO_file_overflow, (f, ch),
       register _IO_FILE* f AND int ch)
 {
   if (f->_flags & _IO_NO_WRITES) /* SET ERROR */
+  {
+    f->_flags |= _IO_ERR_SEEN;
     return EOF;
+  }
   /* If currently reading or no buffer allocated. */
   if ((f->_flags & _IO_CURRENTLY_PUTTING) == 0)
     {
